function [fn,dfn_dy]=eval_fn(y_lin);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This M-file shall contain MATLAB-code for evaluation of the static
% nonlinear quantizer and the corresponding derivative approximation, 
% given an output value of the linear dynamic part of the Wiener model of the 
% algorithms I-V.
%
% Variables:	y_lin = output value of linear block of Wiener model
%              fn = f(y_lin) where f(.) denotes the nonlinear quantizer
%              dfn_dy = df/dy(y_lin) where df/dy denotes the approximation 
%                       of f
%     
% Additional variables may be introduced by the user when implementing a 
% particular nonlinear quantizer.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This implements the nonlinear quantizer. A sum of arctan is used for 
% generation of the approximation of the gradient of the quantizer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
quantGridAlgorithm=[0.5];
quantLevelAlgorithm=[-1.0 1.0];
quantizationSharpness=1.0; % The sharpness of the (default) approximation of the quantizer, 
                           % used for the computation of the gradient 
m=size(quantGridAlgorithm,2);
fn=quantLevelAlgorithm(1,1);
for j=1:m
   if y_lin>quantGridAlgorithm(1,j)
      fn=quantLevelAlgorithm(1,j+1);
   end
end
dfn_dy=0;
for j=1:m
   dfn_dy=dfn_dy+(quantLevelAlgorithm(1,j+1)-quantLevelAlgorithm(1,j))*(1/pi)*quantizationSharpness/(1+quantizationSharpness^2*(y_lin-quantGridAlgorithm(1,j))^2);
end;
