%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Developed by:			Torbjrn Wigren
%                       Division of Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       P O Box 337
%                       SE-751 05 Uppsala
%                       SWEDEN
%
% Version:					1.0, quantization
%
% Date:		        		rev. 1.0, April 10, 2007
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%                       DESCRIPTION
%
% This M-file adds a setup file for initialization of the algorithms I - V of
% Wigren 1990, modified to account for output quantization and FIR systems.
%
% Variables:         B_0 = initial value of the B-polynomial
%                    F_0 = initial value of the F-polynomial
%                    k0 = assumed slope of the static nonlinearity (not for all methods)
%                    lambda0 = rate of gain sequence (0.99 in L&S)
%                    lambda_0 = initial value of gain sequence (0.95 in L&S)
%                    P_0 = initial value of the P-matrix
%                    p_0 = initial value of the scalar p used in the gradient schemes
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
B_0=[0 0 0.02];
F_0=[0 -0.5 0.3];
%F_0=[1]; % FIR Initialization value
k0=1;
lambda0=0.99;
lambda_0=0.95;
P_0=eye(size(B_0,2)+size(F_0,2)-2);
p_0=1;
